==> noahs-2.1.7.tar.gz: noahs/src/Controller/NoahsSaveStylesController.php <==
<?php

namespace Drupal\noahs_page_builder\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Drupal\noahs_page_builder\ControlsManager;
use Drupal\Core\File\FileSystemInterface;
use Drupal\noahs_page_builder_pro\Controller\NoahsBuildThemeProController;
use Drupal\noahs_page_builder\Service\ControlServices;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller routines for domain finder routes.
 */
class NoahsSaveStylesController extends ControllerBase {


  /**
   * Load service.
   *
   * @var \Drupal\noahs_page_builder\Service\ControlServices
   */
  protected $controlService;

  /**
   * NoahsSaveStylesController constructor.
   *
   * @param \Drupal\noahs_page_builder\Service\ControlServices $control_service
   *   The control service used for managing styles.
   */
  public function __construct(ControlServices $control_service) {
    $this->controlService = $control_service;
  }

  /**
   * Creates an instance of the controller.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The instances.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('noahs_page_builder.control_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function save($entity_type, $entity_id) {

    $widgetService = \Drupal::service('noahs_page_builder.widget_service');
    $moduleHandler = \Drupal::service('module_handler');
    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();

    if (!is_numeric($entity_id)) {

      if ($moduleHandler->moduleExists('noahs_page_builder_pro')) {
        $proClass = \Drupal::classResolver(NoahsBuildThemeProController::class);
        $page_settings_data = $proClass->loadNoahsTheme($entity_id) ?? NULL;
      }

    }
    else {
      $page_settings_data = noahs_page_builder_load($langcode, $entity_id, $entity_type);
    }

    if (empty($page_settings_data->settings)) {
      return;
    }

    $page_settings = json_decode($page_settings_data->settings, TRUE);
    $output = '';
    $elements = $this->obtenerElementosRecursivos($page_settings);
    $theme_settings = json_decode($page_settings_data->page_settings, TRUE);
    $output .= $this->obtenerThemeCss($theme_settings['page']);

    foreach ($elements as $item) {

      $fields = $widgetService->getWidgetFields($item['type']);
      $extraFields = $this->controlService->defaultFields();

      if (!empty($fields) && !empty($extraFields)) {

        $mergeField = array_merge($fields, $extraFields);
        $tabs_class = new ControlsManager();

        if (!empty($item['element'])) {
          $css = $this->obtenerCss($item['element']);

          if (!empty($item['element']['css']) || !empty($css)) {
            $arrayUnificado = array_merge_recursive($item['element']['css'], $css);

            $data_controls = $tabs_class->getStyles(
                $mergeField,
                $arrayUnificado,
                $item['wid']
            );
            $output .= PHP_EOL . $data_controls;
          }
        }

      }
    }

    $directory = 'public://noahs/' . $entity_type;
    $file_system = \Drupal::service('file_system');
    $file_system->prepareDirectory($directory, FileSystemInterface:: CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS | FileSystemInterface::EXISTS_REPLACE);

    // Nombre original del archivo.
    $filename = 'noahs_' . $entity_id . '_' . $page_settings_data->langcode . '.css';
    \Drupal::service('file_system')->saveData($output, $directory . '/' . $filename, FileSystemInterface::EXISTS_REPLACE);

    return new JsonResponse(['message' => 'CSS saved!', 'styles' => $output]);

  }

  /**
   * {@inheritdoc}
   */
  private function obtenerElementosRecursivos($array) {
    $elementos = [];

    foreach ($array as $value) {
      if (is_array($value) && isset($value['settings'])) {
        $elementos[] = $value['settings'];
      }

      if (is_array($value)) {
        $elementos = array_merge($elementos, $this->obtenerElementosRecursivos($value));
      }
    }

    return $elementos;
  }

  /**
   * {@inheritdoc}
   */
  private function getAllIds($array, &$ids) {

    foreach ($array as $key => $value) {
      if ($key === 'id') {
        $entry = ['id' => $value];
        if (isset($array['type'])) {
          $entry['type'] = $array['type'];
        }
        $ids[] = $entry;
      }
      elseif (is_array($value)) {
        $this->getAllIds($value, $ids);
      }
    }
    return $ids;
  }

  /**
   * Temporal???.
   */
  public function generateStyles($entity_type, $entity_id) {

    $widgetService = \Drupal::service('noahs_page_builder.widget_service');
    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $output = '';

    $page_settings_data = noahs_page_builder_load($langcode, $entity_id, $entity_type);

    $page_settings = json_decode($page_settings_data->settings, TRUE);
    $elements = $this->obtenerElementosRecursivos($page_settings);

    foreach ($elements as $item) {

      $fields = $widgetService->getWidgetFields($item['type']);
      $extraFields = $this->controlService->defaultFields();
      $mergeField = array_merge($fields, $extraFields);

      $tabs_class = new ControlsManager();
      if (!empty($item['element'])) {
        $css = $this->obtenerCss($item['element']);

        if (!empty($item['element']['css']) || !empty($css)) {
          $arrayUnificado = array_merge_recursive($item['element']['css'], $css);

          $data_controls = $tabs_class->getStyles(
                $mergeField,
                $arrayUnificado,
                $item['wid']
            );

          $output .= PHP_EOL . $data_controls;
        }
      }

    }

    return $output;
  }

  /**
   * Temporal???
   */
  public function generateWidgetStyles(array $item) {
    $widgetService = \Drupal::service('noahs_page_builder.widget_service');
    $output = '';

    if (!empty($item['type'])) {

      $fields = $widgetService->getWidgetFields($item['type']);
      $extraFields = $this->controlService->defaultFields();
      $mergeField = array_merge($fields, $extraFields);
      $tabs_class = new ControlsManager();

      if (!empty($item['element'])) {
        $css = $this->obtenerCss($item['element']);

        if (!empty($item['element']['css']) || !empty($css)) {
          $arrayUnificado = array_merge_recursive($item['element']['css'], $css);

          $data_controls = $tabs_class->getStyles(
                $mergeField,
                $arrayUnificado,
                $item['wid']
            );

          $output .= PHP_EOL . $data_controls;
        }
      }
    }
    return $output;
  }

  /**
   * Temporal???
   */
  public function update(Request $request) {
    $widgetService = \Drupal::service('noahs_page_builder.widget_service');

    $output = '';
    $data = json_decode($request->getContent(), TRUE);
    $item = $data['formData'];
    $fields = $widgetService->getWidgetFields($item['type']);
    $extraFields = $this->controlService->defaultFields();
    $mergeField = array_merge($fields, $extraFields);

    $tabs_class = new ControlsManager();

    if (!empty($item['element'])) {
      $css = $this->obtenerCss($item['element']);

      if (!empty($item['element']['css']) || !empty($css)) {
        $arrayUnificado = array_merge_recursive($item['element']['css'], $css);

        $data_controls = $tabs_class->getStyles(
              $mergeField,
              $arrayUnificado,
              $item['wid']
          );

        $output .= PHP_EOL . $data_controls;
      }
    }

    return new JsonResponse([
      'styles' => $output,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function obtenerCss($element) {
    $cssArray = [];

    foreach ($element as $clave => $subelement) {
      if ($clave !== "css" && $clave !== "class") {
        if (is_array($subelement)) {
          foreach ($subelement as $style) {

            if (isset($style['css'])) {
              $cssArray[] = $style['css'];
            }
          }
        }
      }
    }
    $unifiedArray = call_user_func_array('array_merge_recursive', $cssArray);

    return $unifiedArray;
  }

  /**
   * {@inheritdoc}
   */
  public function obtenerThemeCss($element) {

    $css = '';
    if (!empty($element['site_logo_width'])) {
      $css .= '.noahs-pro-theme--header.sticky img.site__logo{max-width:' . $element['site_logo_width'] . ' !important;}';
    }
    if (!empty($element['background_color_scroll'])) {
      $css .= '.noahs-pro-theme--header.sticky {background-color:' . $element['background_color_scroll'] . ' !important;}';
    }
    if (!empty($element['background_color'])) {
      $css .= 'body{background-color:' . $element['background_color'] . ' !important;}';
    }
    if (!empty($element['header_background_color'])) {
      $css .= 'header{background-color:' . $element['header_background_color'] . ' !important;}';
    }

    return $css;
  }

}

==> noahs-2.1.8.tar.gz: noahs/src/Controller/NoahsSaveStylesController.php <==
<?php

namespace Drupal\noahs_page_builder\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Drupal\noahs_page_builder\ControlsManager;
use Drupal\Core\File\FileSystemInterface;
use Drupal\noahs_page_builder_pro\Controller\NoahsBuildThemeProController;
use Drupal\noahs_page_builder\Service\ControlServices;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller routines for domain finder routes.
 */
class NoahsSaveStylesController extends ControllerBase {


  /**
   * Load service.
   *
   * @var \Drupal\noahs_page_builder\Service\ControlServices
   */
  protected $controlService;

  /**
   * NoahsSaveStylesController constructor.
   *
   * @param \Drupal\noahs_page_builder\Service\ControlServices $control_service
   *   The control service used for managing styles.
   */
  public function __construct(ControlServices $control_service) {
    $this->controlService = $control_service;
  }

  /**
   * Creates an instance of the controller.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The instances.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('noahs_page_builder.control_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function save($entity_type, $entity_id) {

    $widgetService = \Drupal::service('noahs_page_builder.widget_service');
    $moduleHandler = \Drupal::service('module_handler');
    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();

    if (!is_numeric($entity_id)) {

      if ($moduleHandler->moduleExists('noahs_page_builder_pro')) {
        $proClass = \Drupal::classResolver(NoahsBuildThemeProController::class);
        $page_settings_data = $proClass->loadNoahsTheme($entity_id) ?? NULL;
      }

    }
    else {
      $page_settings_data = noahs_page_builder_load($langcode, $entity_id, $entity_type);
    }

    if (empty($page_settings_data->settings)) {
      return;
    }

    $page_settings = json_decode($page_settings_data->settings, TRUE);
    $output = '';
    $elements = $this->obtenerElementosRecursivos($page_settings);
    $theme_settings = json_decode($page_settings_data->page_settings, TRUE);
    $output .= $this->obtenerThemeCss($theme_settings['page']);

    foreach ($elements as $item) {


      $if_token = empty($item['element']['if_token']) ? true : false;
      $fields = $widgetService->getWidgetFields($item['type']);
      $extraFields = $this->controlService->defaultFields();

      if (!empty($fields) && !empty($extraFields)) {

        $mergeField = array_merge($fields, $extraFields);
        $obtenerThemeCss = new ControlsManager();

        if (!empty($item['element'])) {
          $css = $this->obtenerCss($item['element']);
 
          if (!empty($item['element']['css']) || !empty($css)) {
            $arrayUnificado = array_merge_recursive($item['element']['css'], $css);
            if($if_token){
              $data_controls = $obtenerThemeCss->getStyles(
                  $mergeField,
                  $arrayUnificado,
                  $item['wid']
              );
              $output .= PHP_EOL . $data_controls;
            }
       
          }
        }

      }
    }


    $directory = 'public://noahs/' . $entity_type;
    $file_system = \Drupal::service('file_system');
    $file_system->prepareDirectory($directory, FileSystemInterface:: CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS | FileSystemInterface::EXISTS_REPLACE);

    // Nombre original del archivo.
    $filename = 'noahs_' . $entity_id . '_' . $page_settings_data->langcode . '.css';
    \Drupal::service('file_system')->saveData($output, $directory . '/' . $filename, FileSystemInterface::EXISTS_REPLACE);

    return new JsonResponse(['message' => 'CSS saved!', 'styles' => $output]);

  }

  /**
   * {@inheritdoc}
   */
  private function obtenerElementosRecursivos($array) {
    $elementos = [];

    foreach ($array as $value) {
      if (is_array($value) && isset($value['settings'])) {
        $elementos[] = $value['settings'];
      }

      if (is_array($value)) {
        $elementos = array_merge($elementos, $this->obtenerElementosRecursivos($value));
      }
    }

    return $elementos;
  }

  /**
   * {@inheritdoc}
   */
  private function getAllIds($array, &$ids) {

    foreach ($array as $key => $value) {
      if ($key === 'id') {
        $entry = ['id' => $value];
        if (isset($array['type'])) {
          $entry['type'] = $array['type'];
        }
        $ids[] = $entry;
      }
      elseif (is_array($value)) {
        $this->getAllIds($value, $ids);
      }
    }
    return $ids;
  }

  /**
   * Temporal???.
   */
  public function generateStyles($entity_type, $entity_id) {

    $widgetService = \Drupal::service('noahs_page_builder.widget_service');
    $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $output = '';

    $page_settings_data = noahs_page_builder_load($langcode, $entity_id, $entity_type);

    $page_settings = json_decode($page_settings_data->settings, TRUE);
    $elements = $this->obtenerElementosRecursivos($page_settings);

    foreach ($elements as $item) {

      $fields = $widgetService->getWidgetFields($item['type']);
      $extraFields = $this->controlService->defaultFields();
      $mergeField = array_merge($fields, $extraFields);

      $controlsClass = new ControlsManager();
      if (!empty($item['element'])) {
        $css = $this->obtenerCss($item['element']);

        if (!empty($item['element']['css']) || !empty($css)) {
          $arrayUnificado = array_merge_recursive($item['element']['css'], $css);

          $data_controls = $controlsClass->getStyles(
                $mergeField,
                $arrayUnificado,
                $item['wid']
            );

          $output .= PHP_EOL . $data_controls;
        }
      }

    }

    return $output;
  }

  /**
   * Temporal???
   */
  public function generateWidgetStyles(array $item, $if_token = NULL) {
    $widgetService = \Drupal::service('noahs_page_builder.widget_service');
    $output = '';

    if (!empty($item['type'])) {

      $fields = $widgetService->getWidgetFields($item['type']);
      $extraFields = $this->controlService->defaultFields();
      $mergeField = array_merge($fields, $extraFields);
      $controlsClass = new ControlsManager();

      if (!empty($item['element'])) {
        $css = $this->obtenerCss($item['element']);

        if (!empty($item['element']['css']) || !empty($css)) {
          $arrayUnificado = array_merge_recursive($item['element']['css'], $css);

          $data_controls = $controlsClass->getStyles(
                $mergeField,
                $arrayUnificado,
                $item['wid']
            );

          $output .= PHP_EOL . $data_controls;
        }
      }
    }
    return $output;
  }

  /**
   * Temporal???
   */
  public function update(Request $request) {
    $widgetService = \Drupal::service('noahs_page_builder.widget_service');

    $output = '';
    $data = json_decode($request->getContent(), TRUE);
    $item = $data['formData'];
    $fields = $widgetService->getWidgetFields($item['type']);
    $extraFields = $this->controlService->defaultFields();
    $mergeField = array_merge($fields, $extraFields);

    $controlsClass = new ControlsManager();

    if (!empty($item['element'])) {
      $css = $this->obtenerCss($item['element']);

      if (!empty($item['element']['css']) || !empty($css)) {
        $arrayUnificado = array_merge_recursive($item['element']['css'], $css);

        $data_controls = $controlsClass->getStyles(
              $mergeField,
              $arrayUnificado,
              $item['wid']
          );

        $output .= PHP_EOL . $data_controls;
      }
    }

    return new JsonResponse([
      'styles' => $output,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function obtenerCss($element) {
    $cssArray = [];

    foreach ($element as $clave => $subelement) {
      if ($clave !== "css" && $clave !== "class") {
        if (is_array($subelement)) {
          foreach ($subelement as $style) {

            if (isset($style['css'])) {
              $cssArray[] = $style['css'];
            }
          }
        }
      }
    }
    $unifiedArray = call_user_func_array('array_merge_recursive', $cssArray);

    return $unifiedArray;
  }

  /**
   * {@inheritdoc}
   */
  public function obtenerThemeCss($element) {

    $css = '';
    if (!empty($element['site_logo_width'])) {
      $css .= '.noahs-pro-theme--header.sticky img.site__logo{max-width:' . $element['site_logo_width'] . ' !important;}';
    }
    if (!empty($element['background_color_scroll'])) {
      $css .= '.noahs-pro-theme--header.sticky {background-color:' . $element['background_color_scroll'] . ' !important;}';
    }
    if (!empty($element['background_color'])) {
      $css .= 'body{background-color:' . $element['background_color'] . ' !important;}';
    }
    if (!empty($element['header_background_color'])) {
      $css .= 'header{background-color:' . $element['header_background_color'] . ' !important;}';
    }

    return $css;
  }

}
